package	jp.co.sds_corp.util.daemon.db;

import java.util.Iterator;
import java.util.Vector;

import jp.co.sds_corp.util.common.CmnLog;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.AbstractService;
import jp.co.sds_corp.util.db.DbAccess;
import jp.co.sds_corp.util.db.DbException;
import jp.co.sds_corp.util.db.DbInfo;

/**
* SQL 実行サービスです。
<P>
XMLは以下の形式です。
<PRE>
&lt;Service name="Test" class="jp.co.sds_corp.util.daemon.db.SQLExecuter"&gt;
	&lt;db type="properties"&gt;
		&lt;key&gt;db_key&lt;/key&gt;
	&lt;/db&gt;
	&lt;SQL&gt;dump transaction DB with truncate_only&lt;/SQL&gt;
&lt;/Service&gt;
</PRE>

<P>
db要素は以下の子要素のいずれかを持つことができます。
詳細は{@link DbInfo},{@link DbAccess}を参照してください。

dbキーを指定する場合
<PRE>
	&lt;db type="properties"&gt;
		&lt;key&gt;db_key&lt;/key&gt;
	&lt;/db&gt;
</PRE>

JNDIを使用する場合
<PRE>
	&lt;db&gt;
	&lt;db type="jndi"&gt;
		&lt;context&gt;org.jnp.interfaces.NamingContextFactory&lt;/context&gt;
		&lt;url&gt;localhost&lt;/url&gt;
		&lt;datasource&gt;java:/DefaultDS&lt;/datasource&gt;
	&lt;/db&gt;
</PRE>

JDBCドライバを直接使用する場合
<PRE>
	&lt;db type="jdbc"&gt;
		&lt;driver&gt;com.sybase.jdbc2.jdbc.SybDriver&lt;/driver&gt;
		&lt;url&gt;jdbc:sybase:Tds:localhost:4100/db&lt;/url&gt;
		&lt;user&gt;user&lt;/user&gt;
		&lt;password&gt;password&lt;/password&gt;
	&lt;/db&gt;
</PRE>
<P>
&lt;SQL&gt;要素は複数指定することが可能です。
<P>
*/
public class SQLExecuter extends AbstractService
		implements SQLExecuterMBean
{
	private Vector<String>		vecSql = new Vector<String>();
	private	DbAccess	db;
	private IConfiguration dbconf;

	/**
	* このクラスを設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		dbconf = config.getChild( "db" );
		db = new DbAccess( dbconf );

		Iterator<IConfiguration> itr = config.getChilds( "SQL" );
		while ( itr.hasNext()) {
			IConfiguration c = (IConfiguration )itr.next();
			vecSql.add( c.get() );
		}
	}

	/**
	* SQLを実行します。
	*/
	public void start() {
		setStatus( Status.RUN );
		try {
			db.connect();
			for ( int i = 0; i < vecSql.size(); i++ ) {
				String sql = (String )vecSql.get( i );
				db.execute( sql );
				int cnt = db.getUpdateCount();
				CmnLog.debug( this, "" + cnt + " rows affected." );
			}
			db.commit();
			setStatus( Status.WAIT );
		} catch ( DbException ex ) {
			setStatus( Status.ERROR );
			CmnLog.fatal( this, "db execute error", ex );
		} finally {
			try {
				db.disconnect();
			} catch ( Exception ee ) {
			}
		}
	}

	/**
	* 処理を終了します。
	*/
	public void stop() {
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		config.addChild( dbconf );
		for ( int i = 0; i < vecSql.size(); i++ ) {
			String sql = (String )vecSql.get( i );
			config.addChild( "SQL", sql );
		}
	}

	/**
	* このサービスの文字列表現を返します。
	*/
	public String toString() {
		String ret = super.toString();
		for ( int i = 0; i < vecSql.size(); i++ ) {
			String sql = (String )vecSql.get( i );
			ret += "\n\t\"" + sql + "\"";
		}
		return ret;
	}
}
