package	jp.co.sds_corp.util.daemon.file;

import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;

import jp.co.sds_corp.util.common.CmnLog;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.AbstractService;

/**
* 指定のURLからファイルを取得します。
<P>
XMLは以下の形式です。
<PRE>
&lt;Service name="Test" class="jp.co.sds_corp.util.daemon.file.URLLoader"&gt;
	&lt;url&gt;http://www.sds-corp.co.jp/image/aaa.jpeg&lt;/dir&gt;
	&lt;file&gt;bbb.jpeg&lt;/file&gt;
&lt;/Service&gt;
</PRE>

<P>
*/
public class URLLoader extends AbstractService
{
	URL			url;
	String		file;

	/**
	* このクラスを設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		url = new URL( config.get( "url" ));
		file = config.get( "file" );
	}

	/**
	* ファイルの受信処理を開始します。
	*/
	public void start() {
		setStatus( Status.RUN );
		try {
			FileOutputStream fos = new FileOutputStream( file );
			URLConnection con = url.openConnection();
			con.connect();
			InputStream is = con.getInputStream();
			byte[] buf = new byte[1024];
			for ( ;; ) {
				int nRet = is.read( buf );
				if ( nRet < 0 ) {
					break;
				}
				fos.write( buf, 0, nRet );
			}
			fos.flush();
			fos.close();
		} catch ( Throwable ex ) {
			CmnLog.error( this, "URL read error ", ex );
			setStatus( Status.ERROR );
			return;
		}
		setStatus( Status.WAIT );
	}

	/**
	* ファイルの受信処理を終了します。
	*/
	public void stop() {
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		config.addChild( "url", url.toString() );
		config.addChild( "file", file );
	}

	/**
	* このサービスの文字列表現を返します。
	*/
	public String toString() {
		String ret = super.toString();
		ret += " url=[" + url + "] file=[" + file + "]";
		return ret;
	}
}
