package	jp.co.sds_corp.util.daemon.util;

import jp.co.sds_corp.util.common.CmnLog;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.AbstractService;

/**
* syslogを出力するサービスです。
*/
public class LogService extends AbstractService
{
	/** ログ出力レベル */
	enum Level {
		DEBUG,
		INFO,
		WARN,
		ERROR,
		FATAL;
	}
	Level	level = Level.INFO;
	String	message;

	/**
	* サービスの初期化を行う
	*/
	public void init( IConfiguration config )
		throws Exception
	{
		String lvl = config.get( "level" );
		if ( lvl == null ) {
		} else if ( lvl.equals( "debug" )) {
			level = Level.DEBUG;
		} else if ( lvl.equals( "info" )) {
			level = Level.INFO;
		} else if ( lvl.equals( "warn" )) {
			level = Level.WARN;
		} else if ( lvl.equals( "error" )) {
			level = Level.ERROR;
		} else if ( lvl.equals( "fatal" )) {
			level = Level.FATAL;
		}
		message = config.get( "message" );
		if ( message == null ) {
			message = "";
		}
	}

	/**
	* サービスを開始します。
	*/
	public void start() {
		switch ( level ) {
		case DEBUG: CmnLog.debug( this, message ); break;
		case WARN: CmnLog.warn( this, message ); break;
		case ERROR: CmnLog.error( this, message ); break;
		case FATAL: CmnLog.fatal( this, message ); break;
		default:
		case INFO: CmnLog.info( this, message ); break;
		}
	}

	/**
	* サービスを終了します。
	*/
	public void stop() {
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		String var = getLevelString();
	}

	/**
	* このサービスの文字列表現を返します。
	*/
	public String toString() {
		String ret = super.toString();
		ret += " level=" + getLevelString();
		return ret;
	}

	private String getLevelString() {
		String ret = level.toString();
		return ret;
	}
}

